# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .transcription_create_params import TranscriptionCreateParams as TranscriptionCreateParams
