# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .lite_llm_spend_logs import LiteLlmSpendLogs

__all__ = ["SpendListLogsResponse"]

SpendListLogsResponse: TypeAlias = List[LiteLlmSpendLogs]
