# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["InfoListParams"]


class InfoListParams(TypedDict, total=False):
    litellm_model_id: Optional[str]
